@@ -16,6 +16,11 @@
 
 #include <X11/extensions/panoramiXproto.h>
 
+#include "xorg-server.h"
+#ifdef XSERVER_LIBPCIACCESS
+#include <pciaccess.h>
+#endif
+
 #include "compiler.h"	        /* inb/outb */
 
 #include "xf86PciInfo.h"	/* pci vendor id */
@@ -25,7 +30,6 @@
 
 #include "vgaHW.h"		/* VGA hardware */
 #include "fb.h"
-#include "xaa.h"
 
 #include "xf86cmap.h"		/* xf86HandleColormaps */
 
@@ -33,8 +37,6 @@
 #include "svga_reg.h"
 #include "svga_struct.h"
 
-#include "offscreen_manager.h"
-
 /* Arbitrarily choose max cursor dimensions.  The emulation doesn't care. */
 #define MAX_CURS        32
 
@@ -58,8 +60,12 @@ typedef xXineramaScreenInfo VMWAREXineramaRec, *VMWAREXineramaPtr;
 
 typedef struct {
     EntityInfoPtr pEnt;
+#if XSERVER_LIBPCIACCESS
+    struct pci_device *PciInfo;
+#else
     pciVideoPtr PciInfo;
     PCITAG PciTag;
+#endif
     Bool Primary;
     int depth;
     int bitsPerPixel;
@@ -71,6 +77,7 @@ typedef struct {
     unsigned long fbOffset;
     unsigned long fbPitch;
     unsigned long ioBase;
+    unsigned long portIOBase;
     int maxWidth;
     int maxHeight;
     unsigned int vmwareCapability;
@@ -81,7 +88,6 @@ typedef struct {
     VMWARERegRec SavedReg;
     VMWARERegRec ModeReg;
 
-    DisplayModePtr initialMode;
     DisplayModePtr dynMode1;
     DisplayModePtr dynMode2;
 
@@ -107,7 +113,6 @@ typedef struct {
 
     unsigned char* mmioVirtBase;
     CARD32* vmwareFIFO;
-    Bool hasPitchLockFIFOReg;
 
     xf86CursorInfoPtr CursorInfoRec;
     struct {
@@ -125,23 +130,6 @@ typedef struct {
 
     ScreenRec ScrnFuncs;
 
-    /*
-     * XAA info rec and misc storage
-     */
-    XAAInfoRecPtr xaaInfo;
-    int xaaFGColor;
-    int xaaBGColor;
-    int xaaRop;
-
-    unsigned char* xaaColorExpScanLine[1];
-    unsigned int xaaColorExpSize; /* size of current scan line in DWords */
-
-    Heap* heap;
-    SVGASurface* frontBuffer;
-
-    SVGASurface* curPict;
-    int op;
-
     /*
      * Xinerama state
      */
@@ -154,6 +142,11 @@ typedef struct {
     VMWAREXineramaPtr xineramaNextState;
     unsigned int xineramaNextNumOutputs;
 
+    /*
+     * Xv
+     */
+    DevUnion *videoStreams;
+
 } VMWARERec, *VMWAREPtr;
 
 #define VMWAREPTR(p) ((VMWAREPtr)((p)->driverPrivate))
@@ -191,8 +184,6 @@ static __inline ScrnInfoPtr infoFromScreen(ScreenPtr s) {
 
 #define MOUSE_ID 1
 
-extern const char *vmwareXaaSymbols[];
-
 /*#define DEBUG_LOGGING*/
 #ifdef DEBUG_LOGGING
 # define VmwareLog(args) ErrorF args
@@ -205,6 +196,20 @@ extern const char *vmwareXaaSymbols[];
 /* Undefine this to kill all acceleration */
 #define ACCELERATE_OPS
 
+#if XSERVER_LIBPCIACCESS
+#define VENDOR_ID(p)      (p)->vendor_id
+#define DEVICE_ID(p)      (p)->device_id
+#define SUBVENDOR_ID(p)   (p)->subvendor_id
+#define SUBSYS_ID(p)      (p)->subdevice_id
+#define CHIP_REVISION(p)  (p)->revision
+#else
+#define VENDOR_ID(p)      (p)->vendor
+#define DEVICE_ID(p)      (p)->chipType
+#define SUBVENDOR_ID(p)   (p)->subsysVendor
+#define SUBSYS_ID(p)      (p)->subsysCard
+#define CHIP_REVISION(p)  (p)->chipRev
+#endif
+
 void vmwareWriteReg(
    VMWAREPtr pVMWARE, int index, CARD32 value
    );
@@ -257,23 +262,25 @@ void vmwareCursorHookWrappers(
    );
 
 
-/* vmwarexaa.c */
-Bool vmwareXAAScreenInit(
-   ScreenPtr pScreen
-   );
-
-Bool vmwareXAAModeInit(
-    ScrnInfoPtr pScrn, DisplayModePtr mode
-    );
-
-void vmwareXAACloseScreen(
-   ScreenPtr pScreen
-   );
-
 /* vmwarectrl.c */
 void VMwareCtrl_ExtInit(ScrnInfoPtr pScrn);
 
 /* vmwarexinerama.c */
 void VMwareXinerama_ExtInit(ScrnInfoPtr pScrn);
 
+/* vmwarevideo.c */
+Bool vmwareInitVideo(
+   ScreenPtr pScreen
+   );
+void vmwareVideoEnd(
+   ScreenPtr pScreen
+   );
+Bool vmwareVideoEnabled(
+   VMWAREPtr pVMWARE
+   );
+
+void vmwareCheckVideoSanity(
+   ScrnInfoPtr pScrn
+   );
+
 #endif
